@@ -13,7 +13,3 @@ QUARTER_REPORT = "분기보고서"
 SEMINUAL_REPORT = "반기보고서"
 CONNECTED_FINANCIAL_STATEMENTS = "CONNECTED_FINANCIAL_STATEMENTS"
 NORMAL_FINANCIAL_STATEMENTS = "NORMAL_FINANCIAL_STATEMENTS"
-TABLE_CASE_FIRST = "TABLE_CASE_FIRST_MULTIPLE_TRS"
-TABLE_CASE_WITH_NOTE = "TABLE_CASE_WITH_NOTE"
-TABLE_CASE_SECOND = "TABLE_CASE_SECONDS_ONE_TRS"
-TABLE_CASE_THIRD = "TABLE_CASE_THIRD_TWO_TRS"
